@@ -9,19 +9,18 @@ from pathlib import Path
 import typer
 from rich.logging import RichHandler
 
-__version__ = "0.0.2"
+__version__ = "0.0.3"
 
 logging.basicConfig(
-    level="NOTSET",
+    level=logging.NOTSET,
     format="%(message)s",
-    datefmt="[%X]",
+    datefmt=f"[%X] {__name__}",
     handlers=[RichHandler(rich_tracebacks=True, markup=True, show_path=False)],
 )
-# TODO: find a way to have `nbv` before logging level in the output
 
-log = logging.getLogger("rich")
+log = logging.getLogger(__name__)
 
-app = typer.Typer(name="nbv")
+app = typer.Typer(name="nbv", add_completion=False)
 
 
 def _open_in_web_browser(
@@ -80,23 +79,53 @@ def _try(fn, *args, **kwargs):
         return False
 
 
+def _version_callback(value: bool):
+    if value:
+        typer.echo(f"nbv {__version__}")
+
+        import subprocess
+
+        try:
+            cp = subprocess.run(["jupyter-nbconvert", "--version"], text=True, capture_output=True)
+        except (FileNotFoundError, subprocess.CalledProcessError):
+            pass
+        else:
+            typer.echo(f"using jupyter-nbconvert {cp.stdout}")
+
+        raise typer.Exit()
+
+
 @app.command(no_args_is_help=True, help="View Jupyter notebook in web browser.")
 def main(
-    notebook: str = typer.Argument(..., help="Notebook file to open."),
+    notebook: Path = typer.Argument(..., help="Notebook file to open."),
     theme: str = typer.Option("light", help="HTML theme to use."),
     template: str = typer.Option("lab", help="HTML template to use."),
+    remove_old: bool = typer.Option(False, "--remove-old/",
+        help="First remove old temporary HTML notebook files."),
     debug: bool = typer.Option(False, "--debug/", help="Enable info/debug messages."),
+    version: bool = typer.Option(
+        False, "--version/", help="Print version.", callback=_version_callback, is_eager=True
+    ),
 ) -> int:
     log.setLevel(logging.DEBUG if debug else logging.WARNING)
 
-    p = Path(notebook)
+    if remove_old:
+        import os
+        import tempfile
+
+        to_remove = list(Path(tempfile.gettempdir()).glob("notebook=*_*.html"))
+        log.info(f"Found {len(to_remove)} old notebook HTML files in the temp dir.")
+        for p in to_remove:
+            os.remove(p)
+
+    p = notebook
     if not p.suffix == ".ipynb":
         log.error("Only '.ipynb' files are supported.")
-        return 2
+        raise typer.Exit(2)
 
     if not p.is_file():
         log.error(f"File {p.as_posix()!r} does not exist.")
-        return 2
+        raise typer.Exit(2)
 
     if theme == "dark" and template in {"basic", "classic"}:
         typer.echo(
@@ -105,7 +134,7 @@ def main(
 
     err = _try(_open_in_web_browser, p, theme=theme, template=template, debug=debug)
 
-    return int(err)
+    raise typer.Exit(int(err))
 
 
 if __name__ == "__main__":
